@@ -1,22 +1,22 @@
 """This client generates customer reports on all the samples in workbench."""
 
 import zerorpc
-import pprint
 import os
-import workbench_client
+import client_helper
 
 def run():
     """This client generates customer reports on all the samples in workbench."""
     
     # Grab server args
-    args = workbench_client.grab_server_args()
+    args = client_helper.grab_server_args()
 
     # Start up workbench connection
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
-    results = workbench.batch_work_request('view_customer', {})
-    pprint.pprint(list(results))
+    results = workbench.batch_work_request('view_customer')
+    for customer in results:
+        print customer['customer']
 
 def test():
     """Executes test for customer_report."""
