@@ -25,7 +25,7 @@ def run():
             base_name = os.path.basename(filename)
             if base_name == '.DS_Store': continue
 
-            md5 = workbench.store_sample(base_name, f.read(), 'log')
+            md5 = workbench.store_sample(f.read(), base_name, 'log')
             results = workbench.work_request('view_log_meta', md5)
             print 'Filename: %s\n' % (base_name)
             pprint.pprint(results)
