@@ -29,6 +29,7 @@ try:
     from . import neo_db
     from . import plugin_manager
     from bro import bro_log_reader
+    from . import version
 
 # Okay this happens when you're running workbench in a debugger so having
 # this is super handy and we'll keep it even though it hurts coverage score.
@@ -38,6 +39,7 @@ except ValueError:
     import neo_db
     import plugin_manager
     from bro import bro_log_reader
+    import version
 
 
 class WorkBench(object):
@@ -61,12 +63,9 @@ class WorkBench(object):
         # Needs to be replaced by logger
         self.VERBOSE = False
 
-        # Announce Version
-        try:
-            self.version = sys.modules['workbench'].__version__
-        except (AttributeError, KeyError):
-            self.version = '<Develop>'
-        print '<<< Workbench Version %s >>>' % self.version
+        # Workbench Server Version
+        self.version = version.__version__
+        print '<<< Workbench Server Version %s >>>' % self.version
 
         # Open DataStore
         self.data_store = data_store.DataStore(**store_args)
@@ -93,26 +92,43 @@ class WorkBench(object):
         # Store information about commands and workbench
         self._store_information()
 
+    def version(self):
+        """Return the version of the Workbench server"""
+        return self.version
 
     #######################
     # Sample Methods
     #######################
-    def store_sample(self, filename, input_bytes, type_tag):
+    def store_sample(self, input_bytes, filename, type_tag):
         """ Store a sample into the DataStore.
             Args:
-                filename: name of the file (used purely as meta data not for lookup)
                 input_bytes: the actual bytes of the sample e.g. f.read()
+                filename: name of the file (used purely as meta data not for lookup)
                 type_tag: ('exe','pcap','pdf','json','swf', or ...)
             Returns:
                 the md5 of the sample.
         """
 
+        # Store the sample
+        # md5 = self.data_store.store_sample(input_bytes, filename, type_tag)
+
         # If the sample comes in with an unknown type_tag try to determine it
         if type_tag == 'unknown':
-            print '<<< Unknown File: Trying to Determine Type >>>'
+            print 'Info: Unknown File -- Trying to Determine Type...'
             type_tag = self.guess_type_tag(input_bytes)
+            if type_tag == 'data':
+                print 'Info: File -- Trying to Determine Type from filename...'
+                ext = os.path.splitext(filename)[1][1:]
+                if ext in ['mem','vmem']:
+                    type_tag = 'mem'
+                else:
+                    print 'Alert: Failed to Determine Type for %s' % filename
+                    exit(1) # Temp
+            
+        # Temp
+        md5 = self.data_store.store_sample(input_bytes, filename, type_tag)
 
-        return self.data_store.store_sample(filename, input_bytes, type_tag)
+        return md5
 
     def get_sample(self, md5):
         """ Get a sample from the DataStore.
@@ -149,19 +165,42 @@ class WorkBench(object):
         """
         return self.data_store.has_sample(md5)
 
-    def list_samples(self, predicate={}):
+    def list_samples(self, predicate=None):
         """List all samples that meet the predicate or all if predicate is not specified.
 
-        Args:
-            predicate: Match samples against this predicate (or all if not specified)
+            Args:
+                predicate: Match samples against this predicate (or all if not specified)
 
-        Returns:
-            List of dictionaries with matching samples {'md5':md5, 'filename': 'foo.exe', 'type_tag': 'exe'}
+            Returns:
+                List of dictionaries with matching samples {'md5':md5, 'filename': 'foo.exe', 'type_tag': 'exe'}
         """
         return self.data_store.list_samples(predicate)
 
+    def combine_samples(self, md5_list, filename, type_tag):
+        """Combine samples together. This may have various use cases the most significant 
+           involving a bunch of sample 'chunks' got uploaded and now we combine them together
+
+            Args:
+                md5_list: The list of md5s to combine, order matters!
+                filename: name of the file (used purely as meta data not for lookup)
+                type_tag: ('exe','pcap','pdf','json','swf', or ...)
+            Returns:
+                the computed md5 of the combined samples
+        """
+        total_bytes = ""
+        for md5 in md5_list:
+            total_bytes += self.get_sample(md5)['sample']['raw_bytes']
+            self.remove_sample(md5)
+
+        # Store it
+        return self.store_sample(total_bytes, filename, type_tag)
+
+    def remove_sample(self, md5):
+        """Remove the sample from the data store"""
+        self.data_store.remove_sample(md5)
+
     @zerorpc.stream
-    def stream_sample(self, md5, kwargs={}):
+    def stream_sample(self, md5, kwargs=None):
         """ Stream the sample by giving back a generator, typically used on 'logs'.
             Args:
                 md5: the md5 of the sample
@@ -172,7 +211,7 @@ class WorkBench(object):
         """
 
         # Get the max_rows if specified
-        max_rows = kwargs.get('max_rows', None)      
+        max_rows = kwargs.get('max_rows', None) if kwargs else None
 
         # Grab the sample and it's raw bytes
         sample = self.get_sample(md5)['sample']
@@ -204,18 +243,24 @@ class WorkBench(object):
 
     def guess_type_tag(self, input_bytes):
         """ Try to guess the type_tag for this sample """
-        mime_to_type = {'application/x-dosexec': 'exe',
+        mime_to_type = {'application/jar': 'jar',
+                        'application/java-archive': 'jar',
+                        'application/octet-stream': 'data',
                         'application/pdf': 'pdf',
-                        'application/zip': 'zip',
-                        'application/jar': 'jar',
                         'application/vnd.ms-cab-compressed': 'cab',
-                        'text/plain': 'txt',
+                        'application/vnd.ms-fontobject': 'ms_font',
+                        'application/vnd.tcpdump.pcap': 'pcap',
+                        'application/x-dosexec': 'exe',
+                        'application/x-empty': 'empty',
+                        'application/x-shockwave-flash': 'swf',
+                        'application/zip': 'zip',
                         'image/gif': 'gif',
+                        'text/html': 'html',
                         'image/jpeg': 'jpg',
                         'image/png': 'png',
-                        'text/html': 'html',
-                        'application/vnd.ms-fontobject': 'ms_font',
-                        'application/x-shockwave-flash': 'swf'}
+                        'image/x-icon': 'icon',
+                        'text/plain': 'txt'
+                        }
 
         # See what filemagic can determine
         with magic.Magic(flags=magic.MAGIC_MIME_TYPE) as mag:
@@ -223,7 +268,7 @@ class WorkBench(object):
             if mime_type in mime_to_type:
                 return mime_to_type[mime_type]
             else:
-                print '<<< Sample Type could not be Determined >>>'
+                print 'Alert: Sample Type could not be Determined'
                 return 'unknown'
 
 
@@ -374,7 +419,7 @@ class WorkBench(object):
         return work_results
 
     @zerorpc.stream
-    def batch_work_request(self, worker_name, kwargs={}):
+    def batch_work_request(self, worker_name, kwargs=None):
         """Make a batch work request for an existing set of stored samples.
 
         A subset of sample can be specified with kwargs.
@@ -388,9 +433,9 @@ class WorkBench(object):
         Returns:
             A generator that yields rows of worker output or subfields of the worker output
         """
-        type_tag = kwargs.get('type_tag',None)
-        md5_list = kwargs.get('md5_list',None)
-        subkeys = kwargs.get('subkeys',None)
+        type_tag = kwargs.get('type_tag',None) if kwargs else None
+        md5_list = kwargs.get('md5_list',None) if kwargs else None
+        subkeys = kwargs.get('subkeys',None) if kwargs else None
 
         # If no md5_list specified put all samples (of type type_tag if not None)
         if not md5_list:
@@ -594,7 +639,7 @@ class WorkBench(object):
                 self.store_info(info, name, type_tag='command')
 
         # Stores help text into the workbench information system
-        self.store_info({'help': '<<< Workbench Version %s >>>' % self.version}, 'version', type_tag='help')
+        self.store_info({'help': '<<< Workbench Server Version %s >>>' % self.version}, 'version', type_tag='help')
         self.store_info({'help': self._help_workbench()}, 'workbench', type_tag='help')
         self.store_info({'help': self._help_basic()}, 'basic', type_tag='help')
         self.store_info({'help': self._help_commands()}, 'commands', type_tag='help')
@@ -625,8 +670,8 @@ class WorkBench(object):
                 The newest modification time of any worker in the work chain. 
         """
 
-        # Bottom out on sample or sample_set
-        if worker_name=='sample':
+        # Bottom out on sample or info
+        if worker_name=='sample' or worker_name=='info':
             return datetime.datetime(1970, 1, 1)
 
         my_mod_time = self._get_work_results('info', worker_name)['info']['mod_time']
@@ -713,7 +758,6 @@ def run():
     # Spin up Workbench ZeroRPC
     try:
         store_args = {'uri': datastore_uri, 'database': database, 'worker_cap':worker_cap, 'samples_cap':samples_cap}
-        print '<<< Workbench Server at %s >>>' % ('tcp://0.0.0.0:4242')
         workbench = zerorpc.Server(WorkBench(store_args=store_args), name='workbench', heartbeat=60)
         workbench.bind('tcp://0.0.0.0:4242')
         print '\nWorkbench is ready and feeling super duper!'
