@@ -7,7 +7,12 @@ import gevent.subprocess
 import glob
 import zerorpc
 import pprint
+import gevent
 
+def gsleep():
+    ''' Convenience method for gevent.sleep '''
+    print '*** Gevent Sleep ***'
+    gevent.sleep(0)
 
 class PcapBro(object):
     ''' This worker runs Bro scripts on a pcap file '''
@@ -58,8 +63,7 @@ class PcapBro(object):
         script_path = self.get_bro_script_path()
 
         # Create a temporary directory
-        with self.make_temp_directory() as temp_dir:
-            os.chdir(temp_dir)
+        with self.goto_temp_directory() as temp_dir:
 
             # Get the pcap inputs (filenames)
             print 'pcap_bro: Setting up PCAP inputs...'
@@ -75,6 +79,7 @@ class PcapBro(object):
             self.subprocess_manager(command_line)
 
             # Scrape up all the output log files
+            gsleep()
             print 'pcap_bro: Scraping output logs...'
             my_output = {}
             for output_log in glob.glob('*.log'):
@@ -83,9 +88,10 @@ class PcapBro(object):
                 output_name = os.path.splitext(output_log)[0] + '_log'
                 with open(output_log, 'rb') as bro_file:
                     raw_bytes = bro_file.read()
-                    my_output[output_name] = self.workbench.store_sample(output_name, raw_bytes, 'bro')
+                    my_output[output_name] = self.workbench.store_sample(raw_bytes, output_name, 'bro')
 
             # Scrape any extracted files
+            gsleep()
             print 'pcap_bro: Scraping extracted files...'
             my_output['extracted_files'] = []
             for output_file in glob.glob('extract_files/*'):
@@ -98,7 +104,7 @@ class PcapBro(object):
                     else:
                         type_tag = output_name[-3:]
                     raw_bytes = extracted_file.read()
-                    my_output['extracted_files'].append(self.workbench.store_sample(output_name, raw_bytes, type_tag))
+                    my_output['extracted_files'].append(self.workbench.store_sample(raw_bytes, output_name, type_tag))
 
         # Construct back-pointers to the PCAPs
         if 'sample' in input_data:
@@ -124,16 +130,17 @@ class PcapBro(object):
             raise RuntimeError('%s\npcap_bro had returncode: %d' % (exec_args, sp.returncode))
 
     @contextlib.contextmanager
-    def make_temp_directory(self):
-        ''' Bro temporary directory context manager '''
+    def goto_temp_directory(self):
+        previousDir = os.getcwd()
         temp_dir = tempfile.mkdtemp()
+        os.chdir(temp_dir)
         try:
             yield temp_dir
         finally:
+            # Change back to original directory
+            os.chdir(previousDir)
             # Remove the directory/files
             shutil.rmtree(temp_dir)
-            # Change back to original directory
-            os.chdir(self.orig_dir)
 
     def __del__(self):
         ''' Class Cleanup '''
@@ -152,7 +159,7 @@ def test():
 
     # Generate the input data for this worker
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../data/pcap/http.pcap')
-    md5 = workbench.store_sample('http.pcap', open(data_path, 'rb').read(), 'pcap')
+    md5 = workbench.store_sample(open(data_path, 'rb').read(), 'http.pcap', 'pcap')
     input_data = workbench.get_sample(md5)
 
     # Execute the worker (unit test)
@@ -178,7 +185,7 @@ def test():
 
         with open(filename, 'rb') as pcap_file:
             base_name = os.path.basename(filename)
-            pcap_md5s.append(workbench.store_sample(base_name, pcap_file.read(), 'pcap'))
+            pcap_md5s.append(workbench.store_sample(pcap_file.read(), base_name, 'pcap'))
 
     # Now store the sample set
     set_md5 = workbench.store_sample_set(pcap_md5s)
