@@ -43,7 +43,7 @@ def test():
     import os
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), 
                              '../data/pe/bad/033d91aae8ad29ed9fbb858179271232')     
-    md5 = workbench.store_sample('bad_pe', open(data_path, 'rb').read(), 'exe')
+    md5 = workbench.store_sample(open(data_path, 'rb').read(), 'bad_pe', 'exe')
     input_data = workbench.work_request('meta', md5)
     input_data.update(workbench.work_request('strings', md5))
     input_data.update(workbench.work_request('pe_peid', md5))
